==> docker-client-8.1.2-sources.jar: com/spotify/docker/client/messages/swarm/NetworkAttachment.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.auto.value.AutoValue;
import com.google.common.collect.ImmutableList;

import java.util.List;

@AutoValue
@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public abstract class NetworkAttachment {

  @JsonProperty("Network")
  public abstract Network network();

  @JsonProperty("Addresses")
  public abstract ImmutableList<String> addresses();

  @JsonCreator
  static NetworkAttachment create(
      @JsonProperty("Network") final Network network,
      @JsonProperty("Addresses") final List<String> addresses) {
    return new AutoValue_NetworkAttachment(network, ImmutableList.copyOf(addresses));
  }
}

==> docker-client-8.14.1-sources.jar: com/spotify/docker/client/messages/swarm/NetworkAttachment.java <==
/*-
 * -\-\-
 * docker-client
 * --
 * Copyright (C) 2016 Spotify AB
 * --
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * -/-/-
 */

package com.spotify.docker.client.messages.swarm;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.ANY;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.auto.value.AutoValue;
import com.google.common.collect.ImmutableList;

import java.util.List;

@AutoValue
@JsonAutoDetect(fieldVisibility = ANY, getterVisibility = NONE, setterVisibility = NONE)
public abstract class NetworkAttachment {

  @JsonProperty("Network")
  public abstract Network network();

  @JsonProperty("Addresses")
  public abstract ImmutableList<String> addresses();

  @JsonCreator
  static NetworkAttachment create(
      @JsonProperty("Network") final Network network,
      @JsonProperty("Addresses") final List<String> addresses) {
    final ImmutableList<String> addressesCopy =
            addresses == null
                    ? ImmutableList.<String>of()
                    : ImmutableList.copyOf(addresses);
    return new AutoValue_NetworkAttachment(network, addressesCopy);
  }
}
